@@ -19,8 +19,7 @@ const WorkspaceSwitcherPopup = new Lang.Class({
     Name: 'WorkspaceSwitcherPopup',
 
     _init : function() {
-        this.actor = new St.Widget({ reactive: true,
-                                     x: 0,
+        this.actor = new St.Widget({ x: 0,
                                      y: 0,
                                      width: global.screen_width,
                                      height: global.screen_height,
